# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/extensions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2

from voltha_protos.ext_config_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/extensions.proto',
  package='extension',
  syntax='proto3',
  serialized_options=b'\n\035org.opencord.voltha.extensionZ1github.com/opencord/voltha-protos/v4/go/extension',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1evoltha_protos/extensions.proto\x12\textension\x1a\x1evoltha_protos/ext_config.proto\")\n\x12GetDistanceRequest\x12\x13\n\x0bonuDeviceId\x18\x01 \x01(\t\"\'\n\x13GetDistanceResponse\x12\x10\n\x08\x64istance\x18\x01 \x01(\r\"(\n\x14GetOnuUniInfoRequest\x12\x10\n\x08uniIndex\x18\x01 \x01(\r\"\xc1\x04\n\x15GetOnuUniInfoResponse\x12\x46\n\x08\x61\x64mState\x18\x01 \x01(\x0e\x32\x34.extension.GetOnuUniInfoResponse.AdministrativeState\x12\x44\n\toperState\x18\x02 \x01(\x0e\x32\x31.extension.GetOnuUniInfoResponse.OperationalState\x12\x44\n\tconfigInd\x18\x03 \x01(\x0e\x32\x31.extension.GetOnuUniInfoResponse.ConfigurationInd\"\xc2\x01\n\x10\x43onfigurationInd\x12\n\n\x06UNKOWN\x10\x00\x12\x12\n\x0eTEN_BASE_T_FDX\x10\x01\x12\x16\n\x12HUNDRED_BASE_T_FDX\x10\x02\x12\x18\n\x14GIGABIT_ETHERNET_FDX\x10\x03\x12\x16\n\x12TEN_G_ETHERNET_FDX\x10\x04\x12\x12\n\x0eTEN_BASE_T_HDX\x10\x05\x12\x16\n\x12HUNDRED_BASE_T_HDX\x10\x06\x12\x18\n\x14GIGABIT_ETHERNET_HDX\x10\x07\"G\n\x13\x41\x64ministrativeState\x12\x16\n\x12\x41\x44MSTATE_UNDEFINED\x10\x00\x12\n\n\x06LOCKED\x10\x01\x12\x0c\n\x08UNLOCKED\x10\x02\"F\n\x10OperationalState\x12\x17\n\x13OPERSTATE_UNDEFINED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x83\x01\n\x0fGetValueRequest\x12\x31\n\x08\x64istance\x18\x01 \x01(\x0b\x32\x1d.extension.GetDistanceRequestH\x00\x12\x32\n\x07uniInfo\x18\x02 \x01(\x0b\x32\x1f.extension.GetOnuUniInfoRequestH\x00\x42\t\n\x07request\"\xe0\x02\n\x10GetValueResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".extension.GetValueResponse.Status\x12:\n\terrReason\x18\x02 \x01(\x0e\x32\'.extension.GetValueResponse.ErrorReason\x12\x32\n\x08\x64istance\x18\x03 \x01(\x0b\x32\x1e.extension.GetDistanceResponseH\x00\x12\x33\n\x07uniInfo\x18\x04 \x01(\x0b\x32 .extension.GetOnuUniInfoResponseH\x00\"1\n\x06Status\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"4\n\x0b\x45rrorReason\x12\x14\n\x10REASON_UNDEFINED\x10\x00\x12\x0f\n\x0bUNSUPPORTED\x10\x01\x42\n\n\x08response\"I\n\x0fSetValueRequest\x12+\n\x0c\x61larm_config\x18\x01 \x01(\x0b\x32\x13.config.AlarmConfigH\x00\x42\t\n\x07request\"\xeb\x01\n\x10SetValueResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".extension.SetValueResponse.Status\x12:\n\terrReason\x18\x02 \x01(\x0e\x32\'.extension.SetValueResponse.ErrorReason\"1\n\x06Status\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"4\n\x0b\x45rrorReason\x12\x14\n\x10REASON_UNDEFINED\x10\x00\x12\x0f\n\x0bUNSUPPORTED\x10\x01\"V\n\x15SingleGetValueRequest\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12+\n\x07request\x18\x02 \x01(\x0b\x32\x1a.extension.GetValueRequest\"G\n\x16SingleGetValueResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.extension.GetValueResponse\"V\n\x15SingleSetValueRequest\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12+\n\x07request\x18\x02 \x01(\x0b\x32\x1a.extension.SetValueRequest\"G\n\x16SingleSetValueResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.extension.SetValueResponse2\xb3\x01\n\tExtension\x12R\n\x0bGetExtValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12R\n\x0bSetExtValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponseBR\n\x1dorg.opencord.voltha.extensionZ1github.com/opencord/voltha-protos/v4/go/extensionP\x00\x62\x06proto3'
  ,
  dependencies=[voltha__protos_dot_ext__config__pb2.DESCRIPTOR,],
  public_dependencies=[voltha__protos_dot_ext__config__pb2.DESCRIPTOR,])



_GETONUUNIINFORESPONSE_CONFIGURATIONIND = _descriptor.EnumDescriptor(
  name='ConfigurationInd',
  full_name='extension.GetOnuUniInfoResponse.ConfigurationInd',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_BASE_T_FDX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUNDRED_BASE_T_FDX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIGABIT_ETHERNET_FDX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_G_ETHERNET_FDX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_BASE_T_HDX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUNDRED_BASE_T_HDX', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIGABIT_ETHERNET_HDX', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=442,
  serialized_end=636,
)
_sym_db.RegisterEnumDescriptor(_GETONUUNIINFORESPONSE_CONFIGURATIONIND)

_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE = _descriptor.EnumDescriptor(
  name='AdministrativeState',
  full_name='extension.GetOnuUniInfoResponse.AdministrativeState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADMSTATE_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNLOCKED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=638,
  serialized_end=709,
)
_sym_db.RegisterEnumDescriptor(_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE)

_GETONUUNIINFORESPONSE_OPERATIONALSTATE = _descriptor.EnumDescriptor(
  name='OperationalState',
  full_name='extension.GetOnuUniInfoResponse.OperationalState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERSTATE_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=711,
  serialized_end=781,
)
_sym_db.RegisterEnumDescriptor(_GETONUUNIINFORESPONSE_OPERATIONALSTATE)

_GETVALUERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='extension.GetValueResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1155,
  serialized_end=1204,
)
_sym_db.RegisterEnumDescriptor(_GETVALUERESPONSE_STATUS)

_GETVALUERESPONSE_ERRORREASON = _descriptor.EnumDescriptor(
  name='ErrorReason',
  full_name='extension.GetValueResponse.ErrorReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REASON_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1206,
  serialized_end=1258,
)
_sym_db.RegisterEnumDescriptor(_GETVALUERESPONSE_ERRORREASON)

_SETVALUERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='extension.SetValueResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1155,
  serialized_end=1204,
)
_sym_db.RegisterEnumDescriptor(_SETVALUERESPONSE_STATUS)

_SETVALUERESPONSE_ERRORREASON = _descriptor.EnumDescriptor(
  name='ErrorReason',
  full_name='extension.SetValueResponse.ErrorReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REASON_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1206,
  serialized_end=1258,
)
_sym_db.RegisterEnumDescriptor(_SETVALUERESPONSE_ERRORREASON)


_GETDISTANCEREQUEST = _descriptor.Descriptor(
  name='GetDistanceRequest',
  full_name='extension.GetDistanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='onuDeviceId', full_name='extension.GetDistanceRequest.onuDeviceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=118,
)


_GETDISTANCERESPONSE = _descriptor.Descriptor(
  name='GetDistanceResponse',
  full_name='extension.GetDistanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='extension.GetDistanceResponse.distance', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=159,
)


_GETONUUNIINFOREQUEST = _descriptor.Descriptor(
  name='GetOnuUniInfoRequest',
  full_name='extension.GetOnuUniInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uniIndex', full_name='extension.GetOnuUniInfoRequest.uniIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=201,
)


_GETONUUNIINFORESPONSE = _descriptor.Descriptor(
  name='GetOnuUniInfoResponse',
  full_name='extension.GetOnuUniInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='admState', full_name='extension.GetOnuUniInfoResponse.admState', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operState', full_name='extension.GetOnuUniInfoResponse.operState', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configInd', full_name='extension.GetOnuUniInfoResponse.configInd', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETONUUNIINFORESPONSE_CONFIGURATIONIND,
    _GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE,
    _GETONUUNIINFORESPONSE_OPERATIONALSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=781,
)


_GETVALUEREQUEST = _descriptor.Descriptor(
  name='GetValueRequest',
  full_name='extension.GetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='extension.GetValueRequest.distance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniInfo', full_name='extension.GetValueRequest.uniInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='extension.GetValueRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=784,
  serialized_end=915,
)


_GETVALUERESPONSE = _descriptor.Descriptor(
  name='GetValueResponse',
  full_name='extension.GetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='extension.GetValueResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errReason', full_name='extension.GetValueResponse.errReason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='extension.GetValueResponse.distance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniInfo', full_name='extension.GetValueResponse.uniInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETVALUERESPONSE_STATUS,
    _GETVALUERESPONSE_ERRORREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='extension.GetValueResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=918,
  serialized_end=1270,
)


_SETVALUEREQUEST = _descriptor.Descriptor(
  name='SetValueRequest',
  full_name='extension.SetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarm_config', full_name='extension.SetValueRequest.alarm_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='extension.SetValueRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1272,
  serialized_end=1345,
)


_SETVALUERESPONSE = _descriptor.Descriptor(
  name='SetValueResponse',
  full_name='extension.SetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='extension.SetValueResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errReason', full_name='extension.SetValueResponse.errReason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SETVALUERESPONSE_STATUS,
    _SETVALUERESPONSE_ERRORREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1583,
)


_SINGLEGETVALUEREQUEST = _descriptor.Descriptor(
  name='SingleGetValueRequest',
  full_name='extension.SingleGetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetId', full_name='extension.SingleGetValueRequest.targetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='extension.SingleGetValueRequest.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1671,
)


_SINGLEGETVALUERESPONSE = _descriptor.Descriptor(
  name='SingleGetValueResponse',
  full_name='extension.SingleGetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='extension.SingleGetValueResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1744,
)


_SINGLESETVALUEREQUEST = _descriptor.Descriptor(
  name='SingleSetValueRequest',
  full_name='extension.SingleSetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetId', full_name='extension.SingleSetValueRequest.targetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='extension.SingleSetValueRequest.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1832,
)


_SINGLESETVALUERESPONSE = _descriptor.Descriptor(
  name='SingleSetValueResponse',
  full_name='extension.SingleSetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='extension.SingleSetValueResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1834,
  serialized_end=1905,
)

_GETONUUNIINFORESPONSE.fields_by_name['admState'].enum_type = _GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE
_GETONUUNIINFORESPONSE.fields_by_name['operState'].enum_type = _GETONUUNIINFORESPONSE_OPERATIONALSTATE
_GETONUUNIINFORESPONSE.fields_by_name['configInd'].enum_type = _GETONUUNIINFORESPONSE_CONFIGURATIONIND
_GETONUUNIINFORESPONSE_CONFIGURATIONIND.containing_type = _GETONUUNIINFORESPONSE
_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE.containing_type = _GETONUUNIINFORESPONSE
_GETONUUNIINFORESPONSE_OPERATIONALSTATE.containing_type = _GETONUUNIINFORESPONSE
_GETVALUEREQUEST.fields_by_name['distance'].message_type = _GETDISTANCEREQUEST
_GETVALUEREQUEST.fields_by_name['uniInfo'].message_type = _GETONUUNIINFOREQUEST
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['distance'])
_GETVALUEREQUEST.fields_by_name['distance'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _GETVALUEREQUEST.fields_by_name['uniInfo'])
_GETVALUEREQUEST.fields_by_name['uniInfo'].containing_oneof = _GETVALUEREQUEST.oneofs_by_name['request']
_GETVALUERESPONSE.fields_by_name['status'].enum_type = _GETVALUERESPONSE_STATUS
_GETVALUERESPONSE.fields_by_name['errReason'].enum_type = _GETVALUERESPONSE_ERRORREASON
_GETVALUERESPONSE.fields_by_name['distance'].message_type = _GETDISTANCERESPONSE
_GETVALUERESPONSE.fields_by_name['uniInfo'].message_type = _GETONUUNIINFORESPONSE
_GETVALUERESPONSE_STATUS.containing_type = _GETVALUERESPONSE
_GETVALUERESPONSE_ERRORREASON.containing_type = _GETVALUERESPONSE
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['distance'])
_GETVALUERESPONSE.fields_by_name['distance'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_GETVALUERESPONSE.oneofs_by_name['response'].fields.append(
  _GETVALUERESPONSE.fields_by_name['uniInfo'])
_GETVALUERESPONSE.fields_by_name['uniInfo'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['response']
_SETVALUEREQUEST.fields_by_name['alarm_config'].message_type = voltha__protos_dot_ext__config__pb2._ALARMCONFIG
_SETVALUEREQUEST.oneofs_by_name['request'].fields.append(
  _SETVALUEREQUEST.fields_by_name['alarm_config'])
_SETVALUEREQUEST.fields_by_name['alarm_config'].containing_oneof = _SETVALUEREQUEST.oneofs_by_name['request']
_SETVALUERESPONSE.fields_by_name['status'].enum_type = _SETVALUERESPONSE_STATUS
_SETVALUERESPONSE.fields_by_name['errReason'].enum_type = _SETVALUERESPONSE_ERRORREASON
_SETVALUERESPONSE_STATUS.containing_type = _SETVALUERESPONSE
_SETVALUERESPONSE_ERRORREASON.containing_type = _SETVALUERESPONSE
_SINGLEGETVALUEREQUEST.fields_by_name['request'].message_type = _GETVALUEREQUEST
_SINGLEGETVALUERESPONSE.fields_by_name['response'].message_type = _GETVALUERESPONSE
_SINGLESETVALUEREQUEST.fields_by_name['request'].message_type = _SETVALUEREQUEST
_SINGLESETVALUERESPONSE.fields_by_name['response'].message_type = _SETVALUERESPONSE
DESCRIPTOR.message_types_by_name['GetDistanceRequest'] = _GETDISTANCEREQUEST
DESCRIPTOR.message_types_by_name['GetDistanceResponse'] = _GETDISTANCERESPONSE
DESCRIPTOR.message_types_by_name['GetOnuUniInfoRequest'] = _GETONUUNIINFOREQUEST
DESCRIPTOR.message_types_by_name['GetOnuUniInfoResponse'] = _GETONUUNIINFORESPONSE
DESCRIPTOR.message_types_by_name['GetValueRequest'] = _GETVALUEREQUEST
DESCRIPTOR.message_types_by_name['GetValueResponse'] = _GETVALUERESPONSE
DESCRIPTOR.message_types_by_name['SetValueRequest'] = _SETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetValueResponse'] = _SETVALUERESPONSE
DESCRIPTOR.message_types_by_name['SingleGetValueRequest'] = _SINGLEGETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SingleGetValueResponse'] = _SINGLEGETVALUERESPONSE
DESCRIPTOR.message_types_by_name['SingleSetValueRequest'] = _SINGLESETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SingleSetValueResponse'] = _SINGLESETVALUERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDistanceRequest = _reflection.GeneratedProtocolMessageType('GetDistanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISTANCEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetDistanceRequest)
  })
_sym_db.RegisterMessage(GetDistanceRequest)

GetDistanceResponse = _reflection.GeneratedProtocolMessageType('GetDistanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDISTANCERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetDistanceResponse)
  })
_sym_db.RegisterMessage(GetDistanceResponse)

GetOnuUniInfoRequest = _reflection.GeneratedProtocolMessageType('GetOnuUniInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETONUUNIINFOREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuUniInfoRequest)
  })
_sym_db.RegisterMessage(GetOnuUniInfoRequest)

GetOnuUniInfoResponse = _reflection.GeneratedProtocolMessageType('GetOnuUniInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONUUNIINFORESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetOnuUniInfoResponse)
  })
_sym_db.RegisterMessage(GetOnuUniInfoResponse)

GetValueRequest = _reflection.GeneratedProtocolMessageType('GetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetValueRequest)
  })
_sym_db.RegisterMessage(GetValueRequest)

GetValueResponse = _reflection.GeneratedProtocolMessageType('GetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.GetValueResponse)
  })
_sym_db.RegisterMessage(GetValueResponse)

SetValueRequest = _reflection.GeneratedProtocolMessageType('SetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SetValueRequest)
  })
_sym_db.RegisterMessage(SetValueRequest)

SetValueResponse = _reflection.GeneratedProtocolMessageType('SetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SetValueResponse)
  })
_sym_db.RegisterMessage(SetValueResponse)

SingleGetValueRequest = _reflection.GeneratedProtocolMessageType('SingleGetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEGETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleGetValueRequest)
  })
_sym_db.RegisterMessage(SingleGetValueRequest)

SingleGetValueResponse = _reflection.GeneratedProtocolMessageType('SingleGetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEGETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleGetValueResponse)
  })
_sym_db.RegisterMessage(SingleGetValueResponse)

SingleSetValueRequest = _reflection.GeneratedProtocolMessageType('SingleSetValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SINGLESETVALUEREQUEST,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleSetValueRequest)
  })
_sym_db.RegisterMessage(SingleSetValueRequest)

SingleSetValueResponse = _reflection.GeneratedProtocolMessageType('SingleSetValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _SINGLESETVALUERESPONSE,
  '__module__' : 'voltha_protos.extensions_pb2'
  # @@protoc_insertion_point(class_scope:extension.SingleSetValueResponse)
  })
_sym_db.RegisterMessage(SingleSetValueResponse)


DESCRIPTOR._options = None

_EXTENSION = _descriptor.ServiceDescriptor(
  name='Extension',
  full_name='extension.Extension',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1908,
  serialized_end=2087,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='extension.Extension.GetExtValue',
    index=0,
    containing_service=None,
    input_type=_SINGLEGETVALUEREQUEST,
    output_type=_SINGLEGETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExtValue',
    full_name='extension.Extension.SetExtValue',
    index=1,
    containing_service=None,
    input_type=_SINGLESETVALUEREQUEST,
    output_type=_SINGLESETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSION)

DESCRIPTOR.services_by_name['Extension'] = _EXTENSION

# @@protoc_insertion_point(module_scope)
